@@ -23,9 +23,9 @@ SOFTWARE.
 """
 from tensorflow.keras import Model
 
-from .backbone import CSPDarknet53
-from .head import YOLOv3Head
-from .neck import PANet
+from .backbone import CSPDarknet53, CSPDarknet53Tiny
+from .head import YOLOv3Head, YOLOv3HeadTiny
+from .neck import PANet, PANetTiny
 
 
 class YOLOv4(Model):
@@ -35,12 +35,19 @@ class YOLOv4(Model):
     Bounding Box(BBox)
     """
 
-    def __init__(self, anchors, num_classes: int, xyscales):
+    def __init__(
+        self,
+        anchors,
+        num_classes: int,
+        xyscales,
+        activation0: str = "mish",
+        activation1: str = "leaky",
+    ):
         super(YOLOv4, self).__init__(name="YOLOv4")
-        self.num_classes = num_classes
-
-        self.csp_darknet53 = CSPDarknet53()
-        self.panet = PANet(num_classes=num_classes)
+        self.csp_darknet53 = CSPDarknet53(
+            activation0=activation0, activation1=activation1
+        )
+        self.panet = PANet(num_classes=num_classes, activation=activation1)
         self.yolov3_head = YOLOv3Head(
             anchors=anchors, num_classes=num_classes, xysclaes=xyscales
         )
@@ -83,3 +90,23 @@ class YOLOv4(Model):
         x = self.panet(x)
         x = self.yolov3_head(x)
         return x
+
+
+class YOLOv4Tiny(Model):
+    def __init__(
+        self, anchors, num_classes: int, xyscales, activation: str = "leaky",
+    ):
+        super(YOLOv4Tiny, self).__init__(name="YOLOv4Tiny")
+        self.csp_darknet53_tiny = CSPDarknet53Tiny(activation=activation)
+        self.panet_tiny = PANetTiny(
+            num_classes=num_classes, activation=activation
+        )
+        self.yolov3_head_tiny = YOLOv3HeadTiny(
+            anchors=anchors, num_classes=num_classes, xysclaes=xyscales
+        )
+
+    def call(self, x):
+        x = self.csp_darknet53_tiny(x)
+        x = self.panet_tiny(x)
+        x = self.yolov3_head_tiny(x)
+        return x
