@@ -37,23 +37,37 @@ from ..utility import media, predict
 
 
 class YOLOv4:
-    def __init__(self):
+    def __init__(self, tiny: bool = False):
         """
         Default configuration
         """
-        self.anchors = [
-            [[12, 16], [19, 36], [40, 28]],
-            [[36, 75], [76, 55], [72, 146]],
-            [[142, 110], [192, 243], [459, 401]],
-        ]
+        self.tiny = tiny
+
+        if tiny:
+            self.anchors = [
+                [[23, 27], [37, 58], [81, 82]],
+                [[81, 82], [135, 169], [344, 319]],
+            ]
+        else:
+            self.anchors = [
+                [[12, 16], [19, 36], [40, 28]],
+                [[36, 75], [76, 55], [72, 146]],
+                [[142, 110], [192, 243], [459, 401]],
+            ]
         self.batch_size = 32
         self.subdivision = 16
         self._classes = None
         self._has_weights = False
         self.input_size = 608
         self.model = None
-        self.strides = [8, 16, 32]
-        self.xyscales = [1.2, 1.1, 1.05]
+        if tiny:
+            self.strides = [16, 32]
+        else:
+            self.strides = [8, 16, 32]
+        if tiny:
+            self.xyscales = [1.05, 1.05]
+        else:
+            self.xyscales = [1.2, 1.1, 1.05]
 
     @property
     def anchors(self):
@@ -74,7 +88,10 @@ class YOLOv4:
         elif isinstance(anchors, np.ndarray):
             self._anchors = anchors
 
-        self._anchors = self._anchors.astype(np.float32).reshape(3, 3, 2)
+        if self.tiny:
+            self._anchors = self._anchors.astype(np.float32).reshape(2, 3, 2)
+        else:
+            self._anchors = self._anchors.astype(np.float32).reshape(3, 3, 2)
 
     @property
     def classes(self):
@@ -145,17 +162,29 @@ class YOLOv4:
         elif isinstance(xyscales, np.ndarray):
             self._xyscales = xyscales
 
-    def make_model(self):
+    def make_model(
+        self, activation0: str = "mish", activation1: str = "leaky",
+    ):
         # pylint: disable=missing-function-docstring
         self._has_weights = False
         backend.clear_session()
 
         inputs = layers.Input([self.input_size, self.input_size, 3])
-        self.model = yolov4.YOLOv4(
-            anchors=self.anchors,
-            num_classes=len(self.classes),
-            xyscales=self.xyscales,
-        )
+        if self.tiny:
+            self.model = yolov4.YOLOv4Tiny(
+                anchors=self.anchors,
+                num_classes=len(self.classes),
+                xyscales=self.xyscales,
+                activation=activation1,
+            )
+        else:
+            self.model = yolov4.YOLOv4(
+                anchors=self.anchors,
+                num_classes=len(self.classes),
+                xyscales=self.xyscales,
+                activation0=activation0,
+                activation1=activation1,
+            )
         self.model(inputs)
 
     def load_weights(self, weights_path: str, weights_type: str = "tf"):
@@ -165,21 +194,49 @@ class YOLOv4:
             yolo.load_weights("checkpoints")
         """
         if weights_type == "yolo":
-            weights.load_weights(self.model, weights_path)
+            weights.load_weights(self.model, weights_path, tiny=self.tiny)
         elif weights_type == "tf":
             self.model.load_weights(weights_path).expect_partial()
 
         self._has_weights = True
 
-    def save_as_tflite(self, tflite_path):
+    def save_as_tflite(self, tflite_path, quantization=None, data_set=None):
         """
         Save model and weights as tflite
 
         Usage:
             yolo.save_as_tflite("yolov4.tflite")
+            yolo.save_as_tflite("yolov4-float16.tflite", "float16")
+            yolo.save_as_tflite("yolov4-int.tflite", "int", data_set)
         """
         converter = tf.lite.TFLiteConverter.from_keras_model(self.model)
-        converter.allow_custom_ops = True
+
+        def representative_dataset_gen():
+            for _ in range(20):
+                # pylint: disable=stop-iteration-return
+                # TODO: # of iteration
+                images, _ = next(data_set)
+                yield [tf.cast(images[0:1, ...], tf.float32)]
+
+        if quantization:
+            converter.optimizations = [tf.lite.Optimize.DEFAULT]
+
+        if quantization == "float16":
+            converter.target_spec.supported_types = [tf.float16]
+        elif quantization == "int":
+            converter.representative_dataset = representative_dataset_gen
+        elif quantization == "full_int8":
+            converter.representative_dataset = representative_dataset_gen
+            converter.target_spec.supported_ops = [
+                tf.lite.OpsSet.TFLITE_BUILTINS_INT8
+            ]
+            converter.inference_input_type = tf.int8
+            converter.inference_output_type = tf.int8
+        elif quantization:
+            raise ValueError(
+                "YOLOv4: {} is not a valid option".format(quantization)
+            )
+
         tflite_model = converter.convert()
         with tf.io.gfile.GFile(tflite_path, "wb") as fd:
             fd.write(tflite_model)
